"""
Main interface for forecastquery service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_forecastquery import (
        Client,
        ForecastQueryServiceClient,
    )

    session = Session()
    client: ForecastQueryServiceClient = session.client("forecastquery")
    ```
"""

from .client import ForecastQueryServiceClient

Client = ForecastQueryServiceClient

__all__ = ("Client", "ForecastQueryServiceClient")



"""
Type annotations for forecastquery service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_forecastquery.type_defs import DataPointTypeDef

    data: DataPointTypeDef = ...
    ```
"""

from __future__ import annotations

import sys

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Mapping
else:
    from typing import Dict, List, Mapping
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "DataPointTypeDef",
    "ForecastTypeDef",
    "QueryForecastRequestTypeDef",
    "QueryForecastResponseTypeDef",
    "QueryWhatIfForecastRequestTypeDef",
    "QueryWhatIfForecastResponseTypeDef",
    "ResponseMetadataTypeDef",
)


class DataPointTypeDef(TypedDict):
    Timestamp: NotRequired[str]
    Value: NotRequired[float]


class QueryForecastRequestTypeDef(TypedDict):
    ForecastArn: str
    Filters: Mapping[str, str]
    StartDate: NotRequired[str]
    EndDate: NotRequired[str]
    NextToken: NotRequired[str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class QueryWhatIfForecastRequestTypeDef(TypedDict):
    WhatIfForecastArn: str
    Filters: Mapping[str, str]
    StartDate: NotRequired[str]
    EndDate: NotRequired[str]
    NextToken: NotRequired[str]


class ForecastTypeDef(TypedDict):
    Predictions: NotRequired[Dict[str, List[DataPointTypeDef]]]


class QueryForecastResponseTypeDef(TypedDict):
    Forecast: ForecastTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class QueryWhatIfForecastResponseTypeDef(TypedDict):
    Forecast: ForecastTypeDef
    ResponseMetadata: ResponseMetadataTypeDef



"""
Type annotations for forecastquery service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_forecastquery.client import ForecastQueryServiceClient

    session = Session()
    client: ForecastQueryServiceClient = session.client("forecastquery")
    ```
"""

from __future__ import annotations

import sys
from typing import Any

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import (
    QueryForecastRequestTypeDef,
    QueryForecastResponseTypeDef,
    QueryWhatIfForecastRequestTypeDef,
    QueryWhatIfForecastResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("ForecastQueryServiceClient",)

class Exceptions(BaseClientExceptions):
    ClientError: Type[BotocoreClientError]
    InvalidInputException: Type[BotocoreClientError]
    InvalidNextTokenException: Type[BotocoreClientError]
    LimitExceededException: Type[BotocoreClientError]
    ResourceInUseException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]

class ForecastQueryServiceClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        ForecastQueryServiceClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/#generate_presigned_url)
        """

    def query_forecast(
        self, **kwargs: Unpack[QueryForecastRequestTypeDef]
    ) -> QueryForecastResponseTypeDef:
        """
        Retrieves a forecast for a single item, filtered by the supplied criteria.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery/client/query_forecast.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/#query_forecast)
        """

    def query_what_if_forecast(
        self, **kwargs: Unpack[QueryWhatIfForecastRequestTypeDef]
    ) -> QueryWhatIfForecastResponseTypeDef:
        """
        Retrieves a what-if forecast.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery/client/query_what_if_forecast.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_forecastquery/client/#query_what_if_forecast)
        """
